@@ -1,5 +1,5 @@
 fn main() {
-    let formatter = syslog::Formatter5424 {
+    let formatter = flexi_syslog::Formatter5424 {
         facility: syslog::Facility::LOG_USER,
         hostname: None,
         process: "basic".into(),
